@@ -143,6 +143,8 @@ public:
         maxText_ = text;
         label_   = text;
     }
+    double min() { return from_; }
+    double max() { return to_; }
 
 protected:
     bool last_;
@@ -388,6 +390,7 @@ public:
     void visit(BasicGraphicsObjectContainer&);
     void visit(BasicSceneObject&);
     void visit(AnimationStep&);
+    void visit(MetaDataVisitor&);
     bool positional() { return positional_; }
     bool right() { return magCompare(box_position_, "right"); }
     bool top() { return magCompare(box_position_, "top"); }
@@ -398,10 +401,17 @@ public:
             AutoVector<LegendEntry>::back()->last();
     }
 
+
     const Transformation& transformation() { return LayoutVisitor::transformation(); }
     void transformation(Transformation* transformation) { return LayoutVisitor::transformation(transformation); }
     string format() const { return format_; }
 
+    // Legend entries information, will be added to the metadata information ...
+    static void addLegendInfo(const string&, const string&);
+
+    static vector<map<string, string>> legendEntriesInfo_;
+    static map<string, string> legendInfo_;
+
 protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
     virtual void print(ostream&) const;
