@@ -60,6 +60,7 @@ public:
 };
 
 class GribLoop;
+class GribEntryDecoder;
 
 
 class GribDecoder : public Decoder, public Data, public GribDecoderAttributes {
@@ -283,6 +284,13 @@ private:
         p.print(s);
         return s;
     }
+
+    vector<GribEntryDecoder*> entries_;
+    vector<GribEntryDecoder*>::iterator entry_;
+
+
+    Data* current();
+    Data* next();
 };
 
 
