@@ -1079,10 +1079,11 @@ MAGICS_NO_EXPORT void QtDriver::renderText(const Text& text) const {
     MFloat pheight;
 
     // Check if all the text items has the same font, size, colour  and style
-    MagFont magfontFirst  = (text.textBegin())->font();
+    assert(text.textBegin() != text.textEnd());
+    const MagFont& magfontFirst  = (text.textBegin())->font();
     bool sameFontForItems = true;
     for (vector<NiceText>::const_iterator niceText = text.textBegin(); niceText != text.textEnd(); niceText++) {
-        const MagFont magfont = niceText->font();
+        const MagFont& magfont = niceText->font();
         if (magfont.size() != magfontFirst.size() || magfont.name() != magfontFirst.name() ||
             !(magfont.colour() == magfontFirst.colour()) || magfont.styles() != magfontFirst.styles()) {
             sameFontForItems = false;
@@ -1102,13 +1103,19 @@ MAGICS_NO_EXPORT void QtDriver::renderText(const Text& text) const {
         //----------------------------------------------
 
         if (sameFontForItems) {
-            const MagFont magfont          = magfontFirst;
+            const MagFont& magfont          = magfontFirst;
             const std::set<string>& styles = magfont.styles();
 
             pheight = 72. * magfont.size() / 2.54;  // height in points
             pheight /= dpiResolutionRatio_;
             pheight *= fontSizeFactor_;
 
+            if (pheight < 1.0) 
+                pheight = 1.0;
+            else if (pheight > 200.0) {
+                pheight = 200.0;
+            }    
+            
             QFont font(QString::fromStdString(magfont.name()), pheight);
             font.setPointSizeF(pheight);
 
@@ -1194,13 +1201,19 @@ MAGICS_NO_EXPORT void QtDriver::renderText(const Text& text) const {
             // Find out text width
             int totalWidth = 0;
             for (vector<NiceText>::const_iterator niceText = text.textBegin(); niceText != text.textEnd(); niceText++) {
-                const MagFont magfont          = niceText->font();
+                const MagFont& magfont          = niceText->font();
                 const std::set<string>& styles = magfont.styles();
 
                 pheight = 72. * magfont.size() / 2.54;  // height in points
                 pheight /= dpiResolutionRatio_;
                 pheight *= fontSizeFactor_;
 
+                if (pheight < 1.0) 
+                    pheight = 1.0;
+                else if (pheight > 200.0) {
+                    pheight = 200.0;
+                }    
+                
                 QFont font(QString::fromStdString(magfont.name()), pheight);
                 font.setPointSizeF(pheight);
                 if (styles.find("underlined") != styles.end())
@@ -1227,7 +1240,7 @@ MAGICS_NO_EXPORT void QtDriver::renderText(const Text& text) const {
 
             // Loop for the indidual text items
             for (vector<NiceText>::const_iterator niceText = text.textBegin(); niceText != text.textEnd(); niceText++) {
-                const MagFont magfont          = niceText->font();
+                const MagFont& magfont          = niceText->font();
                 const std::set<string>& styles = magfont.styles();
 
                 pheight = 72. * magfont.size() / 2.54;  // height in points
